@@ -1,7 +1,7 @@
 package App::org2wp;
 
-our $DATE = '2016-12-02'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-12-14'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -75,7 +75,8 @@ draft.
 
 To set more attributes:
 
-    % org2wp post1.org --comment-status open --extra-attrs '{"ping_status":"closed"}'
+    % org2wp post1.org --comment-status open \
+        --extra-attr ping_status=closed --extra-attr sticky=1
 
 _
     args => {
@@ -118,8 +119,10 @@ _
             default => 'closed',
         },
         extra_attrs => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'extra_attr',
             summary => 'Set extra post attributes, e.g. ping_status, post_format, etc',
-            schema => 'hash*',
+            schema => ['hash*', of=>'str*'],
         },
     },
     features => {
@@ -333,7 +336,7 @@ App::org2wp - Publish Org document to WordPress as blog post
 
 =head1 VERSION
 
-This document describes version 0.002 of App::org2wp (from Perl distribution App-org2wp), released on 2016-12-02.
+This document describes version 0.003 of App::org2wp (from Perl distribution App-org2wp), released on 2016-12-14.
 
 =head1 FUNCTIONS
 
@@ -402,7 +405,8 @@ draft.
 
 To set more attributes:
 
- % org2wp post1.org --comment-status open --extra-attrs '{"ping_status":"closed"}'
+ % org2wp post1.org --comment-status open \
+     --extra-attr ping_status=closed --extra-attr sticky=1
 
 This function is not exported.
 
